@@ -8,18 +8,34 @@ using a Metropolis-Hastings Monte Carlo algorithm
  estimates parameter for each locus
  using a Broyden minimization
  
+
+send questions concerning this software to:
+Peter Beerli
+beerli@fsu.edu
+
+Copyright 1997-2002 Peter Beerli and Joseph Felsenstein 
+Copyright 2003-2008 Peter Beerli
+Copyright 2009-2012 Peter Beerli and Michal Palczewski
+
+Permission is hereby granted, free of charge, to any person obtaining a copy
+of this software and associated documentation files (the "Software"), to deal
+in the Software without restriction, including without limitation the rights
+to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
+of the Software, and to permit persons to whom the Software is furnished to do
+so, subject to the following conditions:
+
+The above copyright notice and this permission notice shall be included in all copies
+or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
+INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
+PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
+HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
+CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE
+OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  
- Peter Beerli 1997, Seattle
- beerli@fsu.edu
- 
- Copyright 1996-2002 Peter Beerli and Joseph Felsenstein, Seattle WA
-Copyright 2003-2004 Peter Beerli, Tallahassee FL
- 
- This software is distributed free of charge for non-commercial use
- and is copyrighted. Of course, we do not guarantee that the software
- works and are not responsible for any damage you may cause or have.
- 
- $Id: broyden.c 2035 2012-05-16 20:03:33Z beerli $
+ $Id: broyden.c 2067 2012-07-27 20:59:32Z beerli $
+started 1996
 -------------------------------------------------------*/
 /*! \file broyden.c
 Basic routines for maximum likelihood parameter estimation.
@@ -162,7 +178,7 @@ calc_line_new (helper_fmt * helper, MYREAL a, MYREAL b, MYREAL c,
     {
         mid = (*fpsi) (xmid, helper);
         quadratic_constants (&xguess, low, mid, high, xlow, xmid, xhigh);
-        if (MYISNAN ((float) xguess))
+        if (MYISNAN (xguess))
             return 1.;
         if (xguess < xmid)
         {
@@ -1335,10 +1351,10 @@ force_symmetric_d (MYREAL *gxv, long model, nr_fmt * nr, long nn)
         check_symmetric_d (gxv, nr, nn);
         break;
     case MATRIX_SAMETHETA:
-        calc_symmetric_d (gxv, nr, nn, 0, nr->numpop);
+        calc_symmetric_d (gxv, nr, nn, 0L, nr->numpop);
         break;
     case ISLAND:
-        calc_symmetric_d (gxv, nr, nn, 0, nr->numpop);
+        calc_symmetric_d (gxv, nr, nn, 0L, nr->numpop);
         calc_symmetric_d (gxv, nr, nn, nr->numpop, nr->numpop2);
         break;
     case ISLAND_VARTHETA:
@@ -1483,7 +1499,7 @@ check_symmetric_d (MYREAL *grad, nr_fmt * nr, long nn)
         p++;
     }
     if (z > 0)
-        calc_same_d (grad, nr, nn, 0, nr->numpop);
+        calc_same_d (grad, nr, nn, 0L, nr->numpop);
     p = custm + nr->numpop;
     z = 0;
     for (count = numpop; count < numpop * numpop; count++)
